==> wawa-service-common-0.0.32-20180504.082405-1-sources.jar: cn/com/wawa/common/constants/KeepAliveConstants.java <==
package cn.com.wawa.common.constants;

/**
 * Created by danke on 2017/11/27.
 */
public class KeepAliveConstants {
    private KeepAliveConstants() {
    }

    public interface MQMsgBodyKey{
        String MSG_TYPE = "type";
        String MSG_DATA = "data";
        String MSG_SUM = "sum";
        String MSG_USER = "user";
        String MSG_DATA_ORDERID = "orderId";
        String MSG_DATA_USERID = "userId";
        String MSG_DATA_ROOMID = "roomId";
        String MSG_DATA_ISCHTCHED = "isCatched";

        String MSG_DATA_CATCHERID = "catcherId";
        String MSG_DATA_CATCHER_CAUGHT_NUM = "caughtNum";
        String MSG_DATA_USER_NAME = "userName";
        String MSG_DATA_USER_CATCH_NUM = "userCatchNum";
        String MSG_DATA_USER_CAUGHT_WAWA_NAME = "caughtWawaName";
        String MSG_DATA_USER_CAUGHT_MSG = "caughtWawaMsg";

        String MSG_DATA_CENTER_MSG_UNCHECK_NUM = "centerMsgUnChackNum";

        //电压配置发送娃娃机消息key
        String MSG_CONFIG_MACHINE = "config";
        String MSG_CMD_MACHINE = "cmd";
        String MSG_ID_MACHINE = "machineId";
        String MSG_STRONG_MACHINE = "strong";

        //限时抓娃娃新增data字段
        String MSG_COIN_CERT_NUM = "coinCertNum";//兑换券数量
        String MSG_CUR_CON_NUM = "curConNum";//当前连抓数
        String MSG_CATCHER_NUM = "catcherNum";//总抓中数量
        String MSG_SCORE = "score";//总分
        String MSG_ADD_SCORE = "addScore";//本次加分
        String MSG_MAX_CON_NUM = "maxConNum";//本次加分
        String MSG_USER_FIRST_GAME = "firstGame";//用户是否第一次游戏,1是0否

    }

    public interface CatchedStatus{
        String isCatched = "20300";
        String unCatched = "20301";
    }

    public interface HandlerKey{
        String ONLOOK_HANDLER_KEY = "10001";//客户端围观队列心跳消息类型
        String USER_TALK_KEY = "10002";//用户聊天消息类型
    }

    public interface ProxyPushMsgKey{
        String MSG_USERID = "userId";
        String MSG_CATCHERID = "catcherId";
        String MSG_TYPE = "type";
        String MSG_DATA = "data";
        String MSG_TALK_CXT = "dialogContent";
        String MSG_USER_NAME = "nickName";
        String MSG_SEND_TIME = "sendTime";
        String MSG_DIALOG_TYPE = "dialogType";
        String MSG_USER_TITLE_PIC = "userTitlePic";
    }

    /**
     * 用户进出房间行为标记常量
     */
    public interface UserJoin{
        int USER_IN = 1;
        int USER_OUT = 0;
    }
}

==> wawa-service-common-0.0.37-20180702.065638-2-sources.jar: cn/com/wawa/common/constants/KeepAliveConstants.java <==
package cn.com.wawa.common.constants;

/**
 * Created by danke on 2017/11/27.
 */
public class KeepAliveConstants {
    private KeepAliveConstants() {
    }

    public interface MQMsgBodyKey{
        String MSG_TYPE = "type";
        String MSG_DATA = "data";
        String MSG_SUM = "sum";
        String MSG_USER = "user";
        String MSG_DATA_ORDERID = "orderId";
        String MSG_DATA_USERID = "userId";
        String MSG_DATA_ROOMID = "roomId";
        String MSG_DATA_ISCHTCHED = "isCatched";
        String MSG_FIRST_CATCHED = "firstCatched";

        String MSG_DATA_CATCHERID = "catcherId";
        String MSG_DATA_CATCHER_CAUGHT_NUM = "caughtNum";
        String MSG_DATA_USER_NAME = "userName";
        String MSG_DATA_USER_CATCH_NUM = "userCatchNum";
        String MSG_DATA_USER_CAUGHT_WAWA_NAME = "caughtWawaName";
        String MSG_DATA_USER_CAUGHT_MSG = "caughtWawaMsg";

        String MSG_DATA_CENTER_MSG_UNCHECK_NUM = "centerMsgUnChackNum";

        //电压配置发送娃娃机消息key
        String MSG_CONFIG_MACHINE = "config";
        String MSG_CMD_MACHINE = "cmd";
        String MSG_ID_MACHINE = "machineId";
        String MSG_STRONG_MACHINE = "strong";

        //限时抓娃娃新增data字段
        String MSG_COIN_CERT_NUM = "coinCertNum";//兑换券数量
        String MSG_CUR_CON_NUM = "curConNum";//当前连抓数
        String MSG_CATCHER_NUM = "catcherNum";//总抓中数量
        String MSG_SCORE = "score";//总分
        String MSG_ADD_SCORE = "addScore";//本次加分
        String MSG_MAX_CON_NUM = "maxConNum";//本次加分
        String MSG_USER_FIRST_GAME = "firstGame";//用户是否第一次游戏,1是0否

        //限时抓娃娃2.0推送消息字段
        String MSG_BATTLE_RESULT = "result";//结果字段
        String MSG_BATTLE_NEED_AGAIN = "needAgain";//是否需要再次加入匹配
        String MSG_EXIT_USER_ID = "exitUserId";//中途退出用户id
        String MSG_BATTLE_ID = "battleId";//对局id
        String MSG_DATA_MONEY = "money";//游戏结束获取到的money
        String MSG_DATA_PRICE = "price";//显示玩法抽取费率
        String MSG_USER_LIST = "userList";//用户列表key
        String MSG_PLAYERS_SCORE = "totalScore";//对战玩家总分字段
        String MSG_USER_AVATAR_FRAME = "uFrame";
        String MSG_USER_NEW_RECORD = "newRec";//是否新纪录 1-是 0-否
        String MSG_USER_AVATAR = "avatar";//头像
        String MSG_NICK_NAME = "nickName";//昵称
    }

    public interface CatchedStatus{
        String isCatched = "20300";
        String unCatched = "20301";
    }

    public interface HandlerKey{
        String ONLOOK_HANDLER_KEY = "10001";//客户端围观队列心跳消息类型
        String USER_TALK_KEY = "10002";//用户聊天消息类型
    }

    public interface ProxyPushMsgKey{
        String MSG_USERID = "userId";
        String MSG_CATCHERID = "catcherId";
        String MSG_TYPE = "type";
        String MSG_DATA = "data";
        String MSG_TALK_CXT = "dialogContent";
        String MSG_USER_NAME = "nickName";
        String MSG_SEND_TIME = "sendTime";
        String MSG_DIALOG_TYPE = "dialogType";
        String MSG_USER_TITLE_PIC = "userTitlePic";
    }

    /**
     * 用户进出房间行为标记常量
     */
    public interface UserJoin{
        int USER_IN = 1;
        int USER_OUT = 0;
    }
}
